@@ -35,10 +35,10 @@
 
 // Include files for KDE
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <knuminput.h>
 #include <kcolorbutton.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 // Local includes
 
