@@ -44,23 +44,23 @@
 
 // KDE includes
 
-#include <kaboutdata.h>
-#include <kapplication.h>
+#include <tdeaboutdata.h>
+#include <tdeapplication.h>
 #include <kbuttonbox.h>
 #include <kcolorbutton.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
 #include <kdirsize.h>
-#include <kfontdialog.h>
-#include <kglobalsettings.h>
+#include <tdefontdialog.h>
+#include <tdeglobalsettings.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
 #include <klineedit.h>
-#include <klistview.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelistview.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <knuminput.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <ksqueezedtextlabel.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
@@ -82,7 +82,7 @@
 namespace KIPICDArchivingPlugin
 {
 
-KIO::filesize_t TargetMediaSize;
+TDEIO::filesize_t TargetMediaSize;
 
 CDArchivingDialog::CDArchivingDialog( KIPI::Interface* interface, TQWidget *parent)
         : KDialogBase( IconList, i18n("Configure Archive to CD"), Help|Ok|Cancel, Ok,
@@ -100,7 +100,7 @@ CDArchivingDialog::CDArchivingDialog( KIPI::Interface* interface, TQWidget *pare
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("CD/DVD Archiving"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("An Album CD/DVD Archiving Kipi plugin.\n"
                                                      "This plugin use K3b CD/DVD burning software available at\n"
                                                      "http://www.k3b.org"),
@@ -132,13 +132,13 @@ CDArchivingDialog::~CDArchivingDialog()
 
 void CDArchivingDialog::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("cdarchiving", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("cdarchiving", "kipi-plugins");
 }
 
 void CDArchivingDialog::setupSelection(void)
 {
     page_setupSelection = addPage(i18n("Selection"), i18n("Album Selection"),
-                                  BarIcon("folder_image", KIcon::SizeMedium));
+                                  BarIcon("folder_image", TDEIcon::SizeMedium));
 
     TQVBoxLayout *layout = new TQVBoxLayout(page_setupSelection, 0, spacingHint() );
     m_imageCollectionSelector = new KIPI::ImageCollectionSelector(page_setupSelection, m_interface);
@@ -180,7 +180,7 @@ void CDArchivingDialog::setupLookPage(void)
 {
     TQString whatsThis;
     page_setupLook = addPage( i18n("HTML Interface"), i18n("HTML Interface Look"),
-                              BarIcon("html", KIcon::SizeMedium ) );
+                              BarIcon("text-html", TDEIcon::SizeMedium ) );
 
     TQVBoxLayout *vlay = new TQVBoxLayout( page_setupLook, 0, spacingHint() );
 
@@ -263,9 +263,9 @@ void CDArchivingDialog::setupLookPage(void)
 
     m_fontName = new TQComboBox( false, page_setupLook );
     TQStringList standardFonts;
-    KFontChooser::getFontList(standardFonts, 0);
+    TDEFontChooser::getFontList(standardFonts, 0);
     m_fontName->insertStringList( standardFonts );
-    m_fontName->setCurrentText( KGlobalSettings::generalFont().family());
+    m_fontName->setCurrentText( TDEGlobalSettings::generalFont().family());
     TQWhatsThis::add( m_fontName, i18n("<p>Select here the font name used for the pages.") );
 
     m_labelFontName = new TQLabel( i18n("Fon&t name:"), page_setupLook );
@@ -416,7 +416,7 @@ void CDArchivingDialog::setupLookPage(void)
 void CDArchivingDialog::setupCDInfos(void)
 {
     page_CDInfos = addPage( i18n("Volume Descriptor"), i18n("Media Volume Descriptor"),
-                            BarIcon("cd", KIcon::SizeMedium ) );
+                            BarIcon("cd", TDEIcon::SizeMedium ) );
 
     TQVBoxLayout *vlay = new TQVBoxLayout( page_CDInfos, 0, spacingHint() );
 
@@ -500,7 +500,7 @@ void CDArchivingDialog::setupBurning(void)
 {
     page_burning = addPage( i18n("Media Burning"),
                             i18n("CD/DVD Burning Setup"),
-                            BarIcon("cdwriter_unmount", KIcon::SizeMedium ) );
+                            BarIcon("media-optical-cdwriter", TDEIcon::SizeMedium ) );
 
     TQVBoxLayout *vlay = new TQVBoxLayout( page_burning, 0, spacingHint() );
 
@@ -621,8 +621,8 @@ void CDArchivingDialog::ShowMediaCapacity(void)
         Color = "<font color=\"red\">";
 
     m_mediaSize->setText( i18n("Total size: ") + Color +
-                          i18n("<b>%1</b></font> / <b>%2</b>").arg(KIO::convertSizeFromKB(TargetMediaSize))
-                          .arg(KIO::convertSizeFromKB (MaxMediaSize)) );
+                          i18n("<b>%1</b></font> / <b>%2</b>").arg(TDEIO::convertSizeFromKB(TargetMediaSize))
+                          .arg(TDEIO::convertSizeFromKB (MaxMediaSize)) );
 }
 
 void CDArchivingDialog::slotOk()
@@ -637,7 +637,7 @@ void CDArchivingDialog::slotOk()
 
     TQFile fileK3b(getK3bBinPathName());
 
-    if ( !KStandardDirs::findExe( getK3bBinPathName() ))
+    if ( !TDEStandardDirs::findExe( getK3bBinPathName() ))
     {
         KMessageBox::sorry(this, i18n("K3b binary path is not valid. Please check it."));
         return;
