@@ -42,21 +42,21 @@
 
 // Include files for KDE
 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kiconloader.h>
-#include <klistview.h>
+#include <tdelistview.h>
 #include <ksqueezedtextlabel.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kurl.h>
-#include <kio/job.h>
-#include <kio/jobclasses.h>
-#include <kio/netaccess.h>
-#include <kio/global.h>
+#include <tdeio/job.h>
+#include <tdeio/jobclasses.h>
+#include <tdeio/netaccess.h>
+#include <tdeio/global.h>
 #include <kimageio.h>
-#include <kio/previewjob.h>
+#include <tdeio/previewjob.h>
 #include <khelpmenu.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
 
 // Include files for KIPI
@@ -134,7 +134,7 @@ DisplayCompare::DisplayCompare(TQWidget* parent, KIPI::Interface* interface,
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Find Duplicate Images"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to find duplicate images\n"
                                                      "This plugin is based on ShowImg implementation algorithm"),
                                            "(c) 2003-2004, Gilles Caulier");
@@ -191,7 +191,7 @@ DisplayCompare::DisplayCompare(TQWidget* parent, KIPI::Interface* interface,
     originalInfoLabel5 = new KSqueezedTextLabel( GroupBox1, "originalInfoLabel5" );
     originalInfoLabel5->setAlignment( int( TQLabel::AlignCenter ) );
 
-    listName = new KListView( GroupBox1, "listName" );
+    listName = new TDEListView( GroupBox1, "listName" );
     listName->header()->setLabel( 0, i18n( "Files" ) );
     TQWhatsThis::add( listName, i18n( "<p>This list contains all files with many duplicates." ) );
     listName->addColumn( i18n( "Files" ) );
@@ -226,7 +226,7 @@ DisplayCompare::DisplayCompare(TQWidget* parent, KIPI::Interface* interface,
     similarInfoLabel5 = new KSqueezedTextLabel( GroupBox2, "similarInfoLabel5" );
     similarInfoLabel5->setAlignment( int( TQLabel::AlignCenter ) );
 
-    listEq = new KListView( GroupBox2, "listEq" );
+    listEq = new TDEListView( GroupBox2, "listEq" );
     listEq->header()->setLabel( 0, i18n( "Files" ) );
     TQWhatsThis::add( listEq, i18n( "<p>This list contains all duplicates files." ) );
     listEq->addColumn( i18n( "Identical To" ) );
@@ -288,7 +288,7 @@ DisplayCompare::~DisplayCompare()
 
 void DisplayCompare::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("findduplicateimages",
+    TDEApplication::kApplication()->invokeHelp("findduplicateimages",
                                              "kipi-plugins");
 }
 
@@ -307,7 +307,7 @@ void DisplayCompare::slotDelete( void )
            itemTmp = (FindDuplicateItem*)item->nextSibling();
            KURL deleteImage(item->fullpath());
 
-           if ( KIO::NetAccess::del(deleteImage) == false )
+           if ( TDEIO::NetAccess::del(deleteImage) == false )
               KMessageBox::error(this, i18n("Cannot remove duplicate file:\n%1").arg(item->fullpath()));
            else
               m_interface->delImage( deleteImage );
@@ -328,7 +328,7 @@ void DisplayCompare::slotDelete( void )
            {
            KURL deleteImage(item->fullpath());
 
-           if ( KIO::NetAccess::del(deleteImage) == false )
+           if ( TDEIO::NetAccess::del(deleteImage) == false )
               KMessageBox::error(this, i18n("Cannot remove original file:\n%1").arg(item->fullpath()));
 
            item->setOn( false );
@@ -341,7 +341,7 @@ void DisplayCompare::slotDelete( void )
 
 void DisplayCompare::slotDisplayLeft(TQListViewItem * item)
 {
-    KApplication::setOverrideCursor( waitCursor );
+    TDEApplication::setOverrideCursor( waitCursor );
     listEq->clear();
     FindOriginalItem *pitem = static_cast<FindOriginalItem*>( item );
     TQPtrVector < TQFile > *list = (TQPtrVector < TQFile > *)m_cmp.find(pitem->fullpath());
@@ -353,7 +353,7 @@ void DisplayCompare::slotDisplayLeft(TQListViewItem * item)
        originalInfoLabel1->setText(i18n("Image size: %1x%2 pixels").arg(im.width()).arg(im.height()));
        originalInfoLabel2->setText(i18n("File size: 1 byte",
                                         "File size: %n bytes",TQFileInfo(pitem->fullpath()).size()));
-       originalInfoLabel3->setText(i18n("Modified: %1").arg(KLocale(NULL)
+       originalInfoLabel3->setText(i18n("Modified: %1").arg(TDELocale(NULL)
                                    .formatDateTime(TQFileInfo(pitem->fullpath())
                                    .lastModified())));
        originalInfoLabel4->setText(i18n("Album: %1").arg(pitem->album()));
@@ -365,7 +365,7 @@ void DisplayCompare::slotDisplayLeft(TQListViewItem * item)
     TQString IdemIndexed = "file:" + pitem->fullpath();
     KURL url(IdemIndexed);
 
-    KIO::PreviewJob* thumbJob1 = KIO::filePreview( url, preview1->height() );
+    TDEIO::PreviewJob* thumbJob1 = TDEIO::filePreview( url, preview1->height() );
 
     connect(thumbJob1, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
             TQT_SLOT(slotGotPreview1(const KFileItem*, const TQPixmap&)));
@@ -404,7 +404,7 @@ void DisplayCompare::slotDisplayLeft(TQListViewItem * item)
 
     preview2->setPixmap(TQPixmap());
     listEq->setSelected(last, true);
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
 }
 
 
@@ -420,7 +420,7 @@ void DisplayCompare::slotGotPreview1(const KFileItem* /*url*/, const TQPixmap &p
 
 void DisplayCompare::slotDisplayRight(TQListViewItem * item)
 {
-    KApplication::setOverrideCursor( waitCursor );
+    TDEApplication::setOverrideCursor( waitCursor );
     FindDuplicateItem *pitem = static_cast<FindDuplicateItem*>( item );
     TQImage im(pitem->fullpath());
 
@@ -430,7 +430,7 @@ void DisplayCompare::slotDisplayRight(TQListViewItem * item)
        similarInfoLabel1->setText(i18n("Image size: %1x%2 pixels").arg(im.width()).arg(im.height()));
        similarInfoLabel2->setText(i18n("File size: 1 byte",
                                        "File size: %n bytes", TQFileInfo(pitem->fullpath()).size()));
-       similarInfoLabel3->setText(i18n("Modified: %1").arg(KLocale(NULL)
+       similarInfoLabel3->setText(i18n("Modified: %1").arg(TDELocale(NULL)
                                                       .formatDateTime(TQFileInfo(pitem->fullpath())
                                                       .lastModified())));
        similarInfoLabel4->setText(i18n("Album: %1").arg(pitem->album()));
@@ -442,12 +442,12 @@ void DisplayCompare::slotDisplayRight(TQListViewItem * item)
     TQString IdemIndexed = "file:" + pitem->fullpath();
     KURL url(IdemIndexed);
 
-    KIO::PreviewJob* thumbJob2 = KIO::filePreview( url, preview2->height() );
+    TDEIO::PreviewJob* thumbJob2 = TDEIO::filePreview( url, preview2->height() );
 
     connect(thumbJob2, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
             TQT_SLOT(slotGotPreview2(const KFileItem*, const TQPixmap&)));
 
-    KApplication::restoreOverrideCursor();
+    TDEApplication::restoreOverrideCursor();
     }
 
 
