@@ -37,20 +37,20 @@
 
 #include <klineedit.h>
 #include <khelpmenu.h>
-#include <kpopupmenu.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kapplication.h>
+#include <tdepopupmenu.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <khtml_part.h>
-#include <khtmlview.h>
+#include <tdehtml_part.h>
+#include <tdehtmlview.h>
 #include <ktabwidget.h>
 #include <krun.h>
 #include <kdebug.h>
-#include <kconfig.h>
-#include <kdeversion.h>
+#include <tdeconfig.h>
+#include <tdeversion.h>
 #if KDE_IS_VERSION(3,2,0)
-#include <kwallet.h>
+#include <tdewallet.h>
 #endif
 
 // Libkipi includes.
@@ -116,7 +116,7 @@ FlickrWindow::FlickrWindow(KIPI::Interface* interface, const TQString &tmpFolder
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Flickr Export"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Kipi plugin to export image collection to "
                                                      "Flickr web service."),
                                            "(c) 2005-2008, Vardhman Jain\n"
@@ -220,7 +220,7 @@ FlickrWindow::~FlickrWindow()
 
 void FlickrWindow::readSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("FlickrExport Settings");
     m_token = config.readEntry("token");
 
@@ -256,7 +256,7 @@ void FlickrWindow::readSettings()
 
 void FlickrWindow::writeSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("FlickrExport Settings");
     config.writeEntry("token", m_token);
     config.writeEntry("Resize", m_resizeCheckBox->isChecked());
@@ -273,7 +273,7 @@ void FlickrWindow::writeSettings()
 
 void FlickrWindow::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("flickrexport", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("flickrexport", "kipi-plugins");
 }
 
 void FlickrWindow::slotDoLogin()
@@ -334,8 +334,8 @@ void FlickrWindow::slotAlbums( const TQValueList<GAlbum>& albumList )
     //m_photoView->write( "<html></html>" );
     //m_photoView->end();
 
-    KIconLoader* iconLoader = KApplication::kApplication()->iconLoader();
-    TQPixmap pix = iconLoader->loadIcon( "folder", KIcon::NoGroup, 32 );
+    TDEIconLoader* iconLoader = TDEApplication::kApplication()->iconLoader();
+    TQPixmap pix = iconLoader->loadIcon( "folder", TDEIcon::NoGroup, 32 );
 
     typedef TQValueList<GAlbum> GAlbumList;
     GAlbumList::const_iterator iter;
