@@ -25,8 +25,8 @@
 #include <tqimage.h>
 #include <tqregexp.h>
 
-#include <klocale.h>
-#include <kio/job.h>
+#include <tdelocale.h>
+#include <tdeio/job.h>
 #include <kdebug.h>
 #include <kmimetype.h>
 #include <kstandarddirs.h>
@@ -77,13 +77,13 @@ void GalleryTalker::login( const KURL& url, const TQString& name,
     form.addPair("password",         passwd);
     form.finish();
 
-    KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(m_url, form.formData(), false);
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = GE_LOGIN;
     m_job   = job;
@@ -103,14 +103,14 @@ void GalleryTalker::listAlbums()
     form.addPair("protocol_version", "2.11");
     form.finish();
 
-    KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(m_url, form.formData(), false);
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = GE_LISTALBUMS;
     m_job   = job;
@@ -133,14 +133,14 @@ void GalleryTalker::listPhotos( const TQString& albumName )
     form.addPair("set_albumName",    albumName);
     form.finish();
 
-    KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(m_url, form.formData(), false);
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = GE_LISTPHOTOS;
     m_job   = job;
@@ -172,14 +172,14 @@ void GalleryTalker::createAlbum( const TQString& parentAlbumName,
         form.addPair("newAlbumDesc", albumCaption);
     form.finish();
 
-    KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(m_url, form.formData(), false);
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = GE_CREATEALBUM;
     m_job   = job;
@@ -247,14 +247,14 @@ bool GalleryTalker::addPhoto( const TQString& albumName,
 
     form.finish();
 
-    KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(m_url, form.formData(), false);
     job->addMetaData("content-type", form.contentType());
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     m_state = GE_ADDPHOTO;
     m_job   = job;
@@ -273,7 +273,7 @@ void GalleryTalker::cancel()
     }
 }
 
-void GalleryTalker::data(KIO::Job*, const TQByteArray& data)
+void GalleryTalker::data(TDEIO::Job*, const TQByteArray& data)
 {
     if (data.isEmpty())
         return;
@@ -283,7 +283,7 @@ void GalleryTalker::data(KIO::Job*, const TQByteArray& data)
     memcpy(m_buffer.data()+oldSize, data.data(), data.size());
 }
 
-void GalleryTalker::slotResult(KIO::Job *job)
+void GalleryTalker::slotResult(TDEIO::Job *job)
 {
     m_job = 0;
     emit signalBusy( false );
