@@ -35,21 +35,21 @@
 // KDE includes.
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
 #include <khelpmenu.h>
 #include <ksqueezedtextlabel.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
-#include <klistview.h>
-#include <kfiledialog.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
-#include <kglobalsettings.h>
+#include <tdelistview.h>
+#include <tdefiledialog.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
+#include <tdeglobalsettings.h>
 #include <knuminput.h>
 #include <kseparator.h>
-#include <kio/previewjob.h>
+#include <tdeio/previewjob.h>
 
 // Local includes.
 
@@ -89,7 +89,7 @@ public:
 
     TQCheckBox                *interpolateBox;
 
-    KListView                *listView;
+    TDEListView                *listView;
 
     KIntSpinBox              *maxGapInput;
     KIntSpinBox              *maxTimeInput;
@@ -127,7 +127,7 @@ GPSSyncDialog::GPSSyncDialog( KIPI::Interface* interface, TQWidget* parent)
 
     // --------------------------------------------------------------
 
-    d->listView = new KListView(plainPage());
+    d->listView = new TDEListView(plainPage());
     d->listView->addColumn( i18n("Thumbnail") );
     d->listView->addColumn( i18n("File Name") );
     d->listView->addColumn( i18n("Camera time stamp") );
@@ -247,7 +247,7 @@ GPSSyncDialog::GPSSyncDialog( KIPI::Interface* interface, TQWidget* parent)
 
     d->about = new KIPIPlugins::KPAboutData(I18N_NOOP("GPS Sync"),
                                             0,
-                                            KAboutData::License_GPL,
+                                            TDEAboutData::License_GPL,
                                             I18N_NOOP("A plugin to synchronize images' metadata with a GPS device"),
                                             "(c) 2006-2008, Gilles Caulier");
 
@@ -282,7 +282,7 @@ GPSSyncDialog::~GPSSyncDialog()
 
 void GPSSyncDialog::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("gpssync", "kipi-plugins");
+    TDEApplication::kApplication()->invokeHelp("gpssync", "kipi-plugins");
 }
 
 void GPSSyncDialog::setImages( const KURL::List& images )
@@ -290,7 +290,7 @@ void GPSSyncDialog::setImages( const KURL::List& images )
     for( KURL::List::ConstIterator it = images.begin(); it != images.end(); ++it )
         new GPSListViewItem(d->listView, d->listView->lastItem(), *it);
 
-    KIO::PreviewJob *thumbnailJob = KIO::filePreview(images, 64);
+    TDEIO::PreviewJob *thumbnailJob = TDEIO::filePreview(images, 64);
 
     connect(thumbnailJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
             this, TQT_SLOT(slotGotThumbnail(const KFileItem*, const TQPixmap&)));
@@ -298,7 +298,7 @@ void GPSSyncDialog::setImages( const KURL::List& images )
 
 void GPSSyncDialog::slotLoadGPXFile()
 {
-    KURL loadGPXFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL loadGPXFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                                i18n("%1|GPS Exchange Format").arg("*.gpx"), this,
                                                i18n("Select GPX File to Load") );
     if( loadGPXFile.isEmpty() )
@@ -382,7 +382,7 @@ bool GPSSyncDialog::promptUserClose()
 
 void GPSSyncDialog::readSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("GPS Sync Settings");
     d->maxGapInput->setValue(config.readNumEntry("Max Gap Time", 30));
     d->timeZoneCB->setCurrentItem(config.readNumEntry("Time Zone", 16));  // GMT+00:00
@@ -396,7 +396,7 @@ void GPSSyncDialog::readSettings()
 
 void GPSSyncDialog::saveSettings()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("GPS Sync Settings");
     config.writeEntry("Max Gap Time", d->maxGapInput->value() );
     config.writeEntry("Time Zone", d->timeZoneCB->currentItem() );
