@@ -24,13 +24,13 @@
 #include <tqgl.h>
 #include <iostream>
 #include <tqlabel.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <tqdragobject.h>
 #include <tqbitmap.h>
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <kstandarddirs.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 // local includes.
 #include "viewerwidget.h"
