@@ -17,25 +17,25 @@
 
 #include <libkipi/plugin.h>
 
-class KAction;
+class TDEAction;
 
 class Plugin_iPodExport : public KIPI::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
     Plugin_iPodExport( TQObject *parent, const char* name, const TQStringList &args);
     ~Plugin_iPodExport() { }
 
-    virtual KIPI::Category category( KAction* action ) const;
+    virtual KIPI::Category category( TDEAction* action ) const;
     virtual void setup( TQWidget* widget );
 
 private slots:
     void slotImageUpload();
 
 private:
-    KAction         *m_actionImageUpload;
+    TDEAction         *m_actionImageUpload;
     KIPI::Interface *m_interface;
 };
 
