@@ -48,28 +48,28 @@
 
 // KDE includes
 
-#include <kaccel.h>
+#include <tdeaccel.h>
 #include <kcombobox.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
 #include <kdirlister.h>
-#include <kfiledialog.h>
-#include <kfileitem.h>
-#include <klocale.h>
+#include <tdefiledialog.h>
+#include <tdefileitem.h>
+#include <tdelocale.h>
 #include <kedittoolbar.h>
-#include <kio/job.h>
+#include <tdeio/job.h>
 #include <kkeydialog.h>
 #include <klineeditdlg.h>
-#include <kmessagebox.h>
-#include <kpopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdepopupmenu.h>
 #include <kprogress.h>
 #include <krun.h>
 #include <kservice.h>
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
-#include <kstdaccel.h>
+#include <tdestdaccel.h>
 #include <kurl.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
 #include <kguiitem.h>
@@ -146,7 +146,7 @@ CameraUI::CameraUI() : TQWidget()
 
     m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("KameraKlient"),
                                            0,
-                                           KAboutData::License_GPL,
+                                           TDEAboutData::License_GPL,
                                            I18N_NOOP("A Digital camera interface Kipi plugin"),
                                            "(c) 2003-2004, Renchi Raju\n"
                                            "(c) 2004, Tudor Calin");
@@ -231,7 +231,7 @@ CameraUI::~CameraUI() {
 
 void CameraUI::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("kameraklient",
+    TDEApplication::kApplication()->invokeHelp("kameraklient",
                                              "kipi-plugins");
 }
 
@@ -240,7 +240,7 @@ const CameraType* CameraUI::cameraType() {
 }
 
 void CameraUI::setupAccel() {
-    mCameraUIAccel = new KAccel(this);
+    mCameraUIAccel = new TDEAccel(this);
     mCameraUIAccel->insert("Select All", i18n("Select All"),
 	    		i18n("Select all the images from the camera."),
 			CTRL+Key_A, TQT_TQOBJECT(this), TQT_SLOT(slotSelectAll()));
@@ -479,7 +479,7 @@ void CameraUI::slotCameraDeleteSelected() {
 	return;
     }
     TQString warnMsg(i18n("About to delete these Image(s)\n" "Are you sure?"));
-    if(KMessageBox::warningContinueCancelList(this, warnMsg, deleteList, i18n("Warning"), KGuiItem(i18n("Delete"),"editdelete")) ==  KMessageBox::Continue) {
+    if(KMessageBox::warningContinueCancelList(this, warnMsg, deleteList, i18n("Warning"), KGuiItem(i18n("Delete"),"edit-delete")) ==  KMessageBox::Continue) {
 	CameraIconItem *item = static_cast<CameraIconItem*>(mIconView->firstItem());
         while(item) {
             CameraIconItem *nextItem = static_cast<CameraIconItem *>(item->nextItem());
@@ -642,7 +642,7 @@ void CameraUI::slotChangeDownloadDirectory() {
 }
 
 void CameraUI::writeSettings() {
-    mConfig = new KConfig("kipirc");
+    mConfig = new TDEConfig("kipirc");
     mConfig->setGroup("KameraKlient Settings");
     mConfig->writePathEntry("DownloadDirectory", mDownloadDirectoryEdit->text());
     mConfig->writeEntry("DialogSize", frameSize());
@@ -654,7 +654,7 @@ void CameraUI::writeSettings() {
 }
 
 void CameraUI::readSettings() {
-    mConfig = new KConfig("kipirc");
+    mConfig = new TDEConfig("kipirc");
     mConfig->setGroup("KameraKlient Settings");
     mDownloadDirectoryEdit->setText(mConfig->readPathEntry("DownloadDirectory", "$HOME"));
     resize(mConfig->readSizeEntry("DialogSize"));
