@@ -22,17 +22,17 @@
 
 // KDE includes.
 
-#include <klocale.h>
-#include <kaction.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdeaction.h>
+#include <tdeapplication.h>
 #include <kgenericfactory.h>
 #include <klibloader.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
-#include <kpopupmenu.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
-#include <kglobalsettings.h>
+#include <tdepopupmenu.h>
+#include <tdemessagebox.h>
+#include <tdefiledialog.h>
+#include <tdeglobalsettings.h>
 
 // LibKIPI includes.
 
@@ -65,12 +65,12 @@ void Plugin_MetadataEdit::setup( TQWidget* widget )
 {
     KIPI::Plugin::setup( widget );
 
-    m_actionMetadataEdit = new KActionMenu(i18n("Metadata"),
+    m_actionMetadataEdit = new TDEActionMenu(i18n("Metadata"),
                                0,
                                actionCollection(),
                                "metadataedit");
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Edit EXIF..."),
+    m_actionMetadataEdit->insert(new TDEAction (i18n("Edit EXIF..."),
                                      0,
                                      0,     
                                      this,
@@ -78,7 +78,7 @@ void Plugin_MetadataEdit::setup( TQWidget* widget )
                                      actionCollection(),
                                      "editexif"));
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Remove EXIF..."),
+    m_actionMetadataEdit->insert(new TDEAction (i18n("Remove EXIF..."),
                                      0,
                                      0,     
                                      this,
@@ -86,7 +86,7 @@ void Plugin_MetadataEdit::setup( TQWidget* widget )
                                      actionCollection(),
                                      "removeexif"));
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Import EXIF..."),
+    m_actionMetadataEdit->insert(new TDEAction (i18n("Import EXIF..."),
                                      0,
                                      0,     
                                      this,
@@ -96,7 +96,7 @@ void Plugin_MetadataEdit::setup( TQWidget* widget )
 
     m_actionMetadataEdit->popupMenu()->insertSeparator();
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Edit IPTC..."),
+    m_actionMetadataEdit->insert(new TDEAction (i18n("Edit IPTC..."),
                                      0,
                                      0,     
                                      this,
@@ -104,7 +104,7 @@ void Plugin_MetadataEdit::setup( TQWidget* widget )
                                      actionCollection(),
                                      "editiptc"));
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Remove IPTC..."),
+    m_actionMetadataEdit->insert(new TDEAction (i18n("Remove IPTC..."),
                                      0,
                                      0,     
                                      this,
@@ -112,7 +112,7 @@ void Plugin_MetadataEdit::setup( TQWidget* widget )
                                      actionCollection(),
                                      "removeiptc"));
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Import IPTC..."),
+    m_actionMetadataEdit->insert(new TDEAction (i18n("Import IPTC..."),
                                      0,
                                      0,     
                                      this,
@@ -122,7 +122,7 @@ void Plugin_MetadataEdit::setup( TQWidget* widget )
 
     m_actionMetadataEdit->popupMenu()->insertSeparator();
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Edit Captions..."),
+    m_actionMetadataEdit->insert(new TDEAction (i18n("Edit Captions..."),
                                      0,
                                      0,     
                                      this,
@@ -130,7 +130,7 @@ void Plugin_MetadataEdit::setup( TQWidget* widget )
                                      actionCollection(),
                                      "editcomments"));
 
-    m_actionMetadataEdit->insert(new KAction (i18n("Remove Captions..."),
+    m_actionMetadataEdit->insert(new TDEAction (i18n("Remove Captions..."),
                                      0,
                                      0,     
                                      this,
@@ -228,7 +228,7 @@ void Plugin_MetadataEdit::slotImportExif()
     if ( !images.isValid() || images.images().isEmpty() )
         return;
 
-    KURL importEXIFFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL importEXIFFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                                   TQString(), TQT_TQWIDGET(kapp->activeWindow()),
                                                   i18n("Select File to Import EXIF metadata") );
     if( importEXIFFile.isEmpty() )
@@ -374,7 +374,7 @@ void Plugin_MetadataEdit::slotImportIptc()
     if ( !images.isValid() || images.images().isEmpty() )
         return;
 
-    KURL importIPTCFile = KFileDialog::getOpenURL(KGlobalSettings::documentPath(),
+    KURL importIPTCFile = KFileDialog::getOpenURL(TDEGlobalSettings::documentPath(),
                                                   TQString(), TQT_TQWIDGET(kapp->activeWindow()),
                                                   i18n("Select File to Import IPTC metadata") );
     if( importIPTCFile.isEmpty() )
@@ -578,7 +578,7 @@ void Plugin_MetadataEdit::slotRemoveComments()
     }
 }
 
-KIPI::Category Plugin_MetadataEdit::category( KAction* action ) const
+KIPI::Category Plugin_MetadataEdit::category( TDEAction* action ) const
 {
     if ( action == m_actionMetadataEdit )
        return KIPI::IMAGESPLUGIN;
