@@ -26,18 +26,18 @@
 
 #include <libkipi/plugin.h>
 
-class KAction;
+class TDEAction;
 
 class Plugin_Mpegencoder : public KIPI::Plugin
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 
     Plugin_Mpegencoder(TQObject *parent, const char* name, const TQStringList &args);
     virtual ~Plugin_Mpegencoder();
-    virtual KIPI::Category category( KAction* action ) const;
+    virtual KIPI::Category category( TDEAction* action ) const;
     virtual void setup( TQWidget* widget );
     
 public slots:
@@ -45,7 +45,7 @@ public slots:
     void slotActivate();
 
 private:
-    KAction* m_actionMPEGEncoder;
+    TDEAction* m_actionMPEGEncoder;
 };
 
 
