@@ -40,24 +40,24 @@ extern "C"
 #include <kprogress.h>
 #include <kprocess.h>
 #include <ksimpleconfig.h>
-#include <klistbox.h>
+#include <tdelistbox.h>
 #include <kprinter.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <klineedit.h>
 #include <kdebug.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kcombobox.h>
 #include <kprogress.h>
 #include <kurllabel.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kpushbutton.h>
-#include <kapplication.h>
-#include <kaboutdata.h>
+#include <tdeapplication.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
-#include <kdeversion.h>
-#include <kfontcombo.h>
+#include <tdepopupmenu.h>
+#include <tdeversion.h>
+#include <tdefontcombo.h>
 #include <kcolorcombo.h>
 
 // Local includes
@@ -91,7 +91,7 @@ FrmPrintWizard::FrmPrintWizard(TQWidget *parent, const char *name )
 
   m_about = new KIPIPlugins::KPAboutData(I18N_NOOP("Print Wizard"),
                                          0,
-                                         KAboutData::License_GPL,
+                                         TDEAboutData::License_GPL,
                                          I18N_NOOP("A KIPI plugin to print images"),
                                          "(c) 2003-2004, Todd Shoemaker\n(c) 2007-2008, Angelo Naselli");
 
@@ -104,29 +104,29 @@ FrmPrintWizard::FrmPrintWizard(TQWidget *parent, const char *name )
   
   // setting-up icons on buttons
   BtnBrowseOutputPath->setText("");
-  BtnBrowseOutputPath->setIconSet( SmallIconSet( "fileopen" ) );
+  BtnBrowseOutputPath->setIconSet( SmallIconSet( "document-open" ) );
   BtnPrintOrderDown->setText("");
-  BtnPrintOrderDown->setIconSet( SmallIconSet( "down" ) );
+  BtnPrintOrderDown->setIconSet( SmallIconSet( "go-down" ) );
   BtnPrintOrderUp->setText("");
-  BtnPrintOrderUp->setIconSet( SmallIconSet( "up" ) );
+  BtnPrintOrderUp->setIconSet( SmallIconSet( "go-up" ) );
   BtnPreviewPageUp->setText("");
-  BtnPreviewPageUp->setIconSet( SmallIconSet( "next" ) );
+  BtnPreviewPageUp->setIconSet( SmallIconSet( "go-next" ) );
   BtnPreviewPageDown->setText("");
-  BtnPreviewPageDown->setIconSet( SmallIconSet( "previous" ) );
+  BtnPreviewPageDown->setIconSet( SmallIconSet( "go-previous" ) );
   BtnCropPrev->setText("");
-  BtnCropPrev->setIconSet( SmallIconSet( "previous" ) );
+  BtnCropPrev->setIconSet( SmallIconSet( "go-previous" ) );
   BtnCropNext->setText("");
-  BtnCropNext->setIconSet( SmallIconSet( "next" ) );
+  BtnCropNext->setIconSet( SmallIconSet( "go-next" ) );
   BtnCropRotate->setText("");
   BtnCropRotate->setIconSet( SmallIconSet( "rotate" ) );
 
   // wizard buttons
   TQPushButton *pBtn = backButton ();
   pBtn->setText("");
-  pBtn->setIconSet( SmallIconSet( "previous" ) );
+  pBtn->setIconSet( SmallIconSet( "go-previous" ) );
   pBtn = nextButton ();
   pBtn->setText("");
-  pBtn->setIconSet( SmallIconSet( "next" ) );
+  pBtn->setIconSet( SmallIconSet( "go-next" ) );
 
   m_helpButton = helpButton();
   KHelpMenu* helpMenu = new KHelpMenu(this, m_about, false);
@@ -186,7 +186,7 @@ FrmPrintWizard::FrmPrintWizard(TQWidget *parent, const char *name )
 
   loadSettings();
 
-  m_Proc = new KProcess;
+  m_Proc = new TDEProcess;
   *m_Proc << "kjobviewer" << "--all";
 }
 
@@ -207,7 +207,7 @@ FrmPrintWizard::~FrmPrintWizard()
 
 void FrmPrintWizard::slotHelp()
 {
-  KApplication::kApplication()->invokeHelp("printwizard","kipi-plugins");
+  TDEApplication::kApplication()->invokeHelp("printwizard","kipi-plugins");
 }
 
 void FrmPrintWizard::print( KURL::List fileList, TQString tempPath)
@@ -555,7 +555,7 @@ TQString FrmPrintWizard::captionFormatter(TPhoto *photo, const TQString& format)
   // %l focal length
   str.replace("%f", fi.fileName());
   str.replace("%c", photo->exiv2Iface()->getExifComment());
-  str.replace("%d", KGlobal::locale()->formatDateTime(photo->exiv2Iface()->getImageDateTime(),
+  str.replace("%d", TDEGlobal::locale()->formatDateTime(photo->exiv2Iface()->getImageDateTime(),
                                   false, false));
   str.replace("%t", photo->exiv2Iface()->getExifTagString("Exif.Photo.ExposureTime"));
   str.replace("%i", photo->exiv2Iface()->getExifTagString("Exif.Photo.ISOSpeedRatings"));
@@ -1178,7 +1178,7 @@ void FrmPrintWizard::printPhotos(TQPtrList<TPhoto> photos, TQPtrList<TQRect> lay
   PrgPrintProgress->setProgress(0);
   PrgPrintProgress->setTotalSteps(photos.count());
   this->finishButton()->setEnabled(false);
-  KApplication::kApplication()->processEvents();
+  TDEApplication::kApplication()->processEvents();
 
   TQPainter p;
   p.begin(&printer);
@@ -1192,7 +1192,7 @@ void FrmPrintWizard::printPhotos(TQPtrList<TPhoto> photos, TQPtrList<TQRect> lay
     if (printing)
       printer.newPage();
     PrgPrintProgress->setProgress(current);
-    KApplication::kApplication()->processEvents();
+    TDEApplication::kApplication()->processEvents();
     if (m_cancelPrinting)
     {
       printer.abort();
@@ -1217,7 +1217,7 @@ TQStringList FrmPrintWizard::printPhotosToFile(TQPtrList<TPhoto> photos, TQStrin
   PrgPrintProgress->setProgress(0);
   PrgPrintProgress->setTotalSteps(photos.count());
   this->finishButton()->setEnabled(false);
-  KApplication::kApplication()->processEvents();
+  TDEApplication::kApplication()->processEvents();
 
   unsigned int current = 0;
   int pageCount = 1;
@@ -1269,7 +1269,7 @@ TQStringList FrmPrintWizard::printPhotosToFile(TQPtrList<TPhoto> photos, TQStrin
     pageCount++;
 
     PrgPrintProgress->setProgress(current);
-    KApplication::kApplication()->processEvents();
+    TDEApplication::kApplication()->processEvents();
     if (m_cancelPrinting)
       break;
   }
