@@ -33,15 +33,15 @@
 // KDE includes
 
 #include <kdebug.h>
-#include <klocale.h>
-#include <kapplication.h>
-#include <kio/netaccess.h>
-#include <kfilemetainfo.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
+#include <tdeio/netaccess.h>
+#include <tdefilemetainfo.h>
 #include <kstandarddirs.h>
-#include <kio/job.h>
+#include <tdeio/job.h>
 #include <kzip.h>
-#include <kmessagebox.h>
-#include <kaboutdata.h>
+#include <tdemessagebox.h>
+#include <tdeaboutdata.h>
 #include <ktempdir.h>
 
 // KIPI includes
@@ -112,7 +112,7 @@ SimpleViewerExport::SimpleViewerExport(KIPI::Interface* interface, TQObject *par
     m_simpleViewerFiles.append(viewer);
     m_simpleViewerFiles.append("swfobject.js");
 
-    const KAboutData *data = KApplication::kApplication()->aboutData();
+    const TDEAboutData *data = TDEApplication::kApplication()->aboutData();
     m_hostName             = TQString( data->appName() );
     m_hostURL              = data->homepage();
 
@@ -144,7 +144,7 @@ bool SimpleViewerExport::configure()
 
         configured = true;
 
-        if(KIO::NetAccess::exists(m_configDlg->exportURL(), false, TQT_TQWIDGET(kapp->activeWindow())))
+        if(TDEIO::NetAccess::exists(m_configDlg->exportURL(), false, TQT_TQWIDGET(kapp->activeWindow())))
         {
             int ret = KMessageBox::warningYesNoCancel(TQT_TQWIDGET(kapp->activeWindow()),
                                                       i18n("Target folder %1 already exists.\n"
@@ -154,7 +154,7 @@ bool SimpleViewerExport::configure()
             switch(ret)
             {
                 case KMessageBox::Yes:
-                    if(!KIO::NetAccess::del(m_configDlg->exportURL(), TQT_TQWIDGET(kapp->activeWindow())))
+                    if(!TDEIO::NetAccess::del(m_configDlg->exportURL(), TQT_TQWIDGET(kapp->activeWindow())))
                     {
                         KMessageBox::error(TQT_TQWIDGET(kapp->activeWindow()), i18n("Could not delete %1\n"
                                 "Please choose another export folder").arg(m_configDlg->exportURL()));
@@ -206,7 +206,7 @@ void SimpleViewerExport::startExport()
 
     slotProcess();
 
-#if KDE_VERSION >= 0x30200
+#if TDE_VERSION >= 0x30200
         m_progressDlg->setButtonCancel(KStdGuiItem::close());
 #else
         m_progressDlg->setButtonCancelText(i18n("&Close"));
@@ -270,7 +270,7 @@ void SimpleViewerExport::slotProcess()
                                             .arg(m_configDlg->exportURL()));
         if(ret == KMessageBox::Yes)
         {
-            KIO::NetAccess::del(m_configDlg->exportURL(), TQT_TQWIDGET(kapp->activeWindow()));
+            TDEIO::NetAccess::del(m_configDlg->exportURL(), TQT_TQWIDGET(kapp->activeWindow()));
         }
     }
 
@@ -286,7 +286,7 @@ bool SimpleViewerExport::createExportDirectories()
     m_progressDlg->addedAction(i18n("Creating directories..."), KIPI::StartingMessage);
 
     KURL root = m_configDlg->exportURL();
-    if(!KIO::NetAccess::mkdir(root, TQT_TQWIDGET(kapp->activeWindow())))
+    if(!TDEIO::NetAccess::mkdir(root, TQT_TQWIDGET(kapp->activeWindow())))
     {
         m_progressDlg->addedAction(i18n("Could not create folder '%1'").arg(root.url()),
                                    KIPI::ErrorMessage);
@@ -295,7 +295,7 @@ bool SimpleViewerExport::createExportDirectories()
 
     KURL thumbsDir = m_tempDir->name();
     thumbsDir.addPath("/thumbs");
-    if(!KIO::NetAccess::mkdir(thumbsDir, TQT_TQWIDGET(kapp->activeWindow())))
+    if(!TDEIO::NetAccess::mkdir(thumbsDir, TQT_TQWIDGET(kapp->activeWindow())))
     {
         m_progressDlg->addedAction(i18n("Could not create folder '%1'").arg(thumbsDir.url()),
                                    KIPI::ErrorMessage);
@@ -304,7 +304,7 @@ bool SimpleViewerExport::createExportDirectories()
 
     KURL imagesDir = m_tempDir->name();
     imagesDir.addPath("/images");
-    if(!KIO::NetAccess::mkdir(imagesDir, TQT_TQWIDGET(kapp->activeWindow())))
+    if(!TDEIO::NetAccess::mkdir(imagesDir, TQT_TQWIDGET(kapp->activeWindow())))
     {
         m_progressDlg->addedAction(i18n("Could not create folder '%1'").arg(imagesDir.url()),
                                    KIPI::ErrorMessage);
@@ -572,7 +572,7 @@ bool SimpleViewerExport::copySimpleViewer()
 
     TQString dataDir;
 
-    // Due to its license, simpleviewer is installed in $KDEHOME
+    // Due to its license, simpleviewer is installed in $TDEHOME
     dataDir = locate("data", "kipiplugin_simpleviewerexport/simpleviewer/");
     if(dataDir.isEmpty())
         installSimpleViewer();
@@ -590,7 +590,7 @@ bool SimpleViewerExport::copySimpleViewer()
         files.append(dir.absPath() + "/" + *it);
     }
 
-    // files distributed with the plugin are installed in $KDEDIRS
+    // files distributed with the plugin are installed in $TDEDIRS
     dataDir = locate("data", "kipiplugin_simpleviewerexport/simpleviewer_html/");
     dir.setPath(dataDir);
     entries = dir.entryList(TQDir::Files);
@@ -599,7 +599,7 @@ bool SimpleViewerExport::copySimpleViewer()
         files.append(dir.absPath() + "/" + *it);
     }
     // TODO: catch errors
-    KIO::CopyJob *copyJob = KIO::copy(files, m_configDlg->exportURL(), true);
+    TDEIO::CopyJob *copyJob = TDEIO::copy(files, m_configDlg->exportURL(), true);
 
     m_progressDlg->addedAction(i18n("flash files copied..."), KIPI::SuccessMessage);
 
@@ -613,7 +613,7 @@ bool SimpleViewerExport::upload()
 
     m_progressDlg->addedAction(i18n("Uploading gallery..."), KIPI::StartingMessage);
 
-    if(!KIO::NetAccess::dircopy(m_tempDir->name() + "./", m_configDlg->exportURL(), 0))
+    if(!TDEIO::NetAccess::dircopy(m_tempDir->name() + "./", m_configDlg->exportURL(), 0))
         return false;
 
     m_progressDlg->addedAction(i18n("Gallery uploaded..."), KIPI::SuccessMessage);
