@@ -41,18 +41,18 @@
 
 // Kde includes.
 
-#include <klocale.h>
-#include <kconfig.h>
-#include <kmessagebox.h>
-#include <kapplication.h>
-#include <kaboutdata.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
+#include <tdemessagebox.h>
+#include <tdeapplication.h>
+#include <tdeaboutdata.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kstandarddirs.h>
-#include <kfontdialog.h>
+#include <tdefontdialog.h>
 #include <kcolorbutton.h>
-#include <kio/previewjob.h>
+#include <tdeio/previewjob.h>
 #include <kurl.h>
 
 // libkipi includes
@@ -83,7 +83,7 @@ SlideShowConfig::SlideShowConfig(bool allowSelectedOnly, KIPI::Interface * inter
 
     KIPIPlugins::KPAboutData * about = new KIPIPlugins::KPAboutData(I18N_NOOP("Slide Show"),
                                         0,
-                                        KAboutData::License_GPL,
+                                        TDEAboutData::License_GPL,
                                         I18N_NOOP("A Kipi plugin for image slideshow"),
                                         "(c) 2003-2004, Renchi Raju\n(c) 2007, Valerio Fuoglio");
 
@@ -143,7 +143,7 @@ SlideShowConfig::SlideShowConfig(bool allowSelectedOnly, KIPI::Interface * inter
     
     // Configuration file management 
 
-    m_config = new KConfig("kipirc");
+    m_config = new TDEConfig("kipirc");
     m_config->setGroup("SlideShow Settings");
 
     readSettings();
@@ -607,7 +607,7 @@ void SlideShowConfig::slotImagesFilesSelected( TQListBoxItem *item )
 
     if ( m_thumbJob ) delete m_thumbJob;
 
-    m_thumbJob = KIO::filePreview( url, m_ImageLabel->width() );
+    m_thumbJob = TDEIO::filePreview( url, m_ImageLabel->width() );
 
     connect(m_thumbJob, TQT_SIGNAL(gotPreview(const KFileItem*, const TQPixmap&)),
             TQT_SLOT(slotGotPreview(const KFileItem*, const TQPixmap&)));
@@ -778,7 +778,7 @@ void SlideShowConfig::slotStartClicked()
 
 void SlideShowConfig::slotHelp()
 {
-    KApplication::kApplication()->invokeHelp("slideshow",
+    TDEApplication::kApplication()->invokeHelp("slideshow",
                                              "kipi-plugins");
 }
 
