@@ -24,8 +24,8 @@
 #include <tqimage.h>
 #include <tqregexp.h>
 
-#include <klocale.h>
-#include <kio/job.h>
+#include <tdelocale.h>
+#include <tdeio/job.h>
 #include <kdebug.h>
 #include <kmimetype.h>
 #include <kstandarddirs.h>
@@ -44,7 +44,7 @@
 namespace KIPISyncPlugin
 {
 
-GallerySink::GallerySink(unsigned int sinkId, TQString name, KConfig* pConfig, KWallet::Wallet* pWallet, GalleryVersion version)
+GallerySink::GallerySink(unsigned int sinkId, TQString name, TDEConfig* pConfig, TDEWallet::Wallet* pWallet, GalleryVersion version)
   : Sink(sinkId, name, pConfig, pWallet),
     mVersion(version), 
     mAuthToken(""), 
@@ -70,7 +70,7 @@ const KIPI2::CollectionList* GallerySink::getCollections()
   return NULL;
 }
   
-void GallerySink::Save(KConfig* pConfig, KWallet::Wallet* pWallet)
+void GallerySink::Save(TDEConfig* pConfig, TDEWallet::Wallet* pWallet)
 {
   pConfig->writeEntry(TQString("Name%1").arg(mSinkId), mName);
   pConfig->writeEntry(TQString("Type%1").arg(mSinkId), Type());
@@ -97,13 +97,13 @@ bool GallerySink::Connect()
     form.addPair("uname",            mUsername);
     form.addPair("password",         mPassword);
 
-    KIO::TransferJob* job = KIO::http_post(mURL, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(mURL, form.formData(), false);
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_LOGIN;
     mpJob   = job;
@@ -122,14 +122,14 @@ void GallerySink::listAlbums()
     form.addPair("cmd",              task);
     form.addPair("protocol_version", "2.3");
 
-    KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(m_url, form.formData(), false);
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_LISTALBUMS;
     mpJob   = job;
@@ -151,14 +151,14 @@ void GallerySink::listPhotos( const TQString& albumName )
     form.addPair("protocol_version", "2.3");
     form.addPair("set_albumName",    albumName);
 
-    KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(m_url, form.formData(), false);
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_LISTPHOTOS;
     mpJob   = job;
@@ -189,14 +189,14 @@ void GallerySink::createAlbum( const TQString& parentAlbumName,
     if (!albumCaption.isEmpty())
         form.addPair("newAlbumDesc", albumCaption);
 
-    KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(m_url, form.formData(), false);
     job->addMetaData("content-type", form.contentType() );
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_CREATEALBUM;
     mpJob   = job;
@@ -256,14 +256,14 @@ bool GallerySink::addPhoto( const TQString& albumName,
     if (!form.addFile(path, display_filename))
         return false;
 
-    KIO::TransferJob* job = KIO::http_post(m_url, form.formData(), false);
+    TDEIO::TransferJob* job = TDEIO::http_post(m_url, form.formData(), false);
     job->addMetaData("content-type", form.contentType());
     job->addMetaData("cookies", "manual");
     job->addMetaData("setcookies", m_cookie);
-    connect(job, TQT_SIGNAL(data(KIO::Job*, const TQByteArray&)),
-            TQT_SLOT(data(KIO::Job*, const TQByteArray&)));
-    connect(job, TQT_SIGNAL(result(KIO::Job *)),
-            TQT_SLOT(slotResult(KIO::Job *)));
+    connect(job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+            TQT_SLOT(data(TDEIO::Job*, const TQByteArray&)));
+    connect(job, TQT_SIGNAL(result(TDEIO::Job *)),
+            TQT_SLOT(slotResult(TDEIO::Job *)));
 
     mState = GE_ADDPHOTO;
     mpJob   = job;
@@ -282,7 +282,7 @@ void GallerySink::cancel()
     }
 }
 
-void GallerySink::data(KIO::Job*, const TQByteArray& data)
+void GallerySink::data(TDEIO::Job*, const TQByteArray& data)
 {
     if (data.isEmpty())
         return;
@@ -292,7 +292,7 @@ void GallerySink::data(KIO::Job*, const TQByteArray& data)
     memcpy(mBuffer.data()+oldSize, data.data(), data.size());
 }
 
-void GallerySink::slotResult(KIO::Job *job)
+void GallerySink::slotResult(TDEIO::Job *job)
 {
     mpJob = 0;
     emit signalBusy( false );
